pub struct OtpParameters {
pub secret: Vec<u8>,
pub name: String,
pub issuer: String,
pub algorithm: i32,
pub digits: i32,
pub type: i32,
pub counter: i64,
}Fields
secret: Vec<u8>name: Stringissuer: Stringalgorithm: i32digits: i32type: i32counter: i64Implementations
Sourceimpl OtpParameters
impl OtpParameters
Sourcepub fn algorithm(&self) -> Algorithm
pub fn algorithm(&self) -> Algorithm
Returns the enum value of algorithm, or the default if the field is set to an invalid enum value.
Sourcepub fn set_algorithm(&mut self, value: Algorithm)
pub fn set_algorithm(&mut self, value: Algorithm)
Sets algorithm to the provided enum value.